#!/bin/sh -xe

ln -s "$srcdir/dns.pcap" dns.pcap || true

../dnscap -g -r dns.pcap 2>no-layers.out
../dnscap -g -r dns.pcap -o use_layers=yes 2>layers.out

diff no-layers.out layers.out
